@@ -4,7 +4,6 @@
 #' @description A combination of box and violin plots along with raw
 #'   (unjittered) data points for within-subjects designs with statistical
 #'   details included in the plot as a subtitle.
-#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
 #' @inheritParams ggbetweenstats
 #' @param path.point,path.mean Logical that decides whether individual data
@@ -387,18 +386,19 @@ ggwithinstats <- function(data,
       )
 
     # display the results if needed
-    if (isTRUE(messages)) print(dplyr::select(df_pairwise, -p.value.label))
+    if (isTRUE(messages)) print(dplyr::select(df_pairwise, -label))
 
     # adding the layer for pairwise comparisons
-    plot <- ggsignif_adder(
-      plot = plot,
-      df_pairwise = df_pairwise,
-      data = data,
-      x = {{ x }},
-      y = {{ y }},
-      pairwise.annotation = pairwise.annotation,
-      pairwise.display = pairwise.display
-    )
+    plot <-
+      ggsignif_adder(
+        plot = plot,
+        df_pairwise = df_pairwise,
+        data = data,
+        x = {{ x }},
+        y = {{ y }},
+        pairwise.annotation = pairwise.annotation,
+        pairwise.display = pairwise.display
+      )
 
     # preparing the caption for pairwise comparisons test
     caption <-
